---
name: Support request
about: Ask for help
title: ''
labels: ''
assignees: ''

---

👋 Hello! If you have a question like "How do I do X with `transitions`" or "I have the following problem... Can `transitions` help me with that?", please consider [Stack Overflow](https://stackoverflow.com/questions/tagged/pytransitions) first. 

Your question gains higher visibility since most developers look for help there.
The targeted community is larger; Some people will even help you to formulate a good question.
People get 'rewarded' with 'reputation' to help you. You also gain reputation in case this questions pops up more frequently. It's a win-win situation. Tag your question with `[pytransitions]` to make sure, that users of transitions will receive a notification. If the SO community cannot answer you question within a week, you can notify us by opening an issue here. Make sure to link your Stack Overflow post.  We'd rather answer questions there.

**Checklist** 

- [ ] I checked the [README](https://github.com/pytransitions/transitions/blob/master/README.md) and the [issue tracker](https://github.com/pytransitions/transitions/issues) but did not find an answer.
- [ ] I posted my question on Stack Overflow [here](enter link here) but received no answer after a week.
